@@ -1,7 +1,7 @@
 package DateTime::Format::Duration::ISO8601;
 
 our $DATE = '2017-07-20'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -40,6 +40,7 @@ sub format_duration {
     );
 
     $S += $ns / 1_000_000_000;
+    $d += $w * 7;
 
     my $has_date = $y || $m || $w || $d;
     my $has_time = $H || $M || $S;
@@ -51,7 +52,6 @@ sub format_duration {
         "P",
         ($y, "Y") x !!$y,
         ($m, "M") x !!$m,
-        ($w, "W") x !!$w,
         ($d, "D") x !!$d,
         (
             "T",
@@ -158,7 +158,7 @@ DateTime::Format::Duration::ISO8601 - Format DateTime::Duration object as ISO860
 
 =head1 VERSION
 
-This document describes version 0.003 of DateTime::Format::Duration::ISO8601 (from Perl distribution DateTime-Format-Duration-ISO8601), released on 2017-07-20.
+This document describes version 0.004 of DateTime::Format::Duration::ISO8601 (from Perl distribution DateTime-Format-Duration-ISO8601), released on 2017-07-20.
 
 =head1 SYNOPSIS
 
